@@ -134,6 +134,9 @@ CV_PY_TO_ENUM(ImageMetadataType)
 CV_PY_FROM_ENUM(ImreadModes)
 CV_PY_TO_ENUM(ImreadModes)
 
+CV_PY_FROM_ENUM(ImwriteBMPCompressionFlags)
+CV_PY_TO_ENUM(ImwriteBMPCompressionFlags)
+
 CV_PY_FROM_ENUM(ImwriteEXRCompressionFlags)
 CV_PY_TO_ENUM(ImwriteEXRCompressionFlags)
 
@@ -167,6 +170,9 @@ CV_PY_TO_ENUM(ImwriteTiffCompressionFlags)
 CV_PY_FROM_ENUM(ImwriteTiffPredictorFlags)
 CV_PY_TO_ENUM(ImwriteTiffPredictorFlags)
 
+CV_PY_FROM_ENUM(ImwriteTiffResolutionUnitFlags)
+CV_PY_TO_ENUM(ImwriteTiffResolutionUnitFlags)
+
 CV_PY_FROM_ENUM(InterpolationFlags)
 CV_PY_TO_ENUM(InterpolationFlags)
 
@@ -672,6 +678,18 @@ typedef cv::img_hash::BlockMeanHashMode img_hash_BlockMeanHashMode;
 CV_PY_FROM_ENUM(img_hash_BlockMeanHashMode)
 CV_PY_TO_ENUM(img_hash_BlockMeanHashMode)
 
+typedef cv::instr::FLAGS instr_FLAGS;
+CV_PY_FROM_ENUM(instr_FLAGS)
+CV_PY_TO_ENUM(instr_FLAGS)
+
+typedef cv::instr::IMPL instr_IMPL;
+CV_PY_FROM_ENUM(instr_IMPL)
+CV_PY_TO_ENUM(instr_IMPL)
+
+typedef cv::instr::TYPE instr_TYPE;
+CV_PY_FROM_ENUM(instr_TYPE)
+CV_PY_TO_ENUM(instr_TYPE)
+
 typedef cv::kinfu::VolumeType kinfu_VolumeType;
 CV_PY_FROM_ENUM(kinfu_VolumeType)
 CV_PY_TO_ENUM(kinfu_VolumeType)
@@ -820,6 +838,10 @@ typedef cv::text::page_seg_mode text_page_seg_mode;
 CV_PY_FROM_ENUM(text_page_seg_mode)
 CV_PY_TO_ENUM(text_page_seg_mode)
 
+typedef cv::utils::logging::LogLevel utils_logging_LogLevel;
+CV_PY_FROM_ENUM(utils_logging_LogLevel)
+CV_PY_TO_ENUM(utils_logging_LogLevel)
+
 typedef cv::videostab::MotionModel videostab_MotionModel;
 CV_PY_FROM_ENUM(videostab_MotionModel)
 CV_PY_TO_ENUM(videostab_MotionModel)
